abacusai.realtime_monitor — AbacusAI documentation

# abacusai.realtime_monitor

## Classes

`RealtimeMonitor` | A real-time monitor

## Module Contents

class abacusai.realtime_monitor.RealtimeMonitor(client, realtimeMonitorId=None, name=None, createdAt=None, deploymentId=None, lookbackTime=None, realtimeMonitorSchedule=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A real-time monitor

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - realtimeMonitorId (str) – The unique identifier of the real-time monitor.

    - name (str) – The user-friendly name for the real-time monitor.

    - createdAt (str) – Date and time at which the real-time monitor was created.

    - deploymentId (str) – Deployment ID that this real-time monitor is monitoring.

    - lookbackTime (int) – The lookback time for the real-time monitor.

    - realtimeMonitorSchedule (str) – The drift computation schedule for the real-time monitor.

  realtime_monitor_id = None
  name = None
  created_at = None
  deployment_id = None
  lookback_time = None
  realtime_monitor_schedule = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

  update(realtime_monitor_schedule=None, lookback_time=None)

    Update the real-time monitor associated with the real-time monitor id.

    Parameters:

      - realtime_monitor_schedule (str) – The cron expression for triggering monitor

      - lookback_time (float) – Lookback time (in seconds) for each monitor trigger

    Returns:

      Object describing the realtime monitor.

    Return type:

      RealtimeMonitor

  refresh()

    Calls describe and refreshes the current object’s fields

    Returns:

      The current object

    Return type:

      RealtimeMonitor

  describe()

    Get the real-time monitor associated with the real-time monitor id.

    Parameters:

      realtime_monitor_id (str) – Unique string identifier for the real-time monitor.

    Returns:

      Object describing the real-time monitor.

    Return type:

      RealtimeMonitor

  delete()

    Delete the real-time monitor associated with the real-time monitor id.

    Parameters:

      realtime_monitor_id (str) – Unique string identifier for the real-time monitor.